diff --git a/src/or/hs_common.c b/src/or/hs_common.c
index 291d8ae8da..f10fc4d5a4 100644
--- a/src/or/hs_common.c
+++ b/src/or/hs_common.c
@@ -235,7 +235,7 @@ get_time_period_length(void)
}
/** Get the HS time period number at time now. If now is not set,
* we try to get the time ourselves. */
uint64_t
hs_get_time_period_num(time_t now)
{
@@ -269,22 +269,26 @@ hs_get_time_period_num(time_t now)
}
/** Get the number of the _upcoming_ HS time period, given that the current
- * time is now. */
+ * time is now. If now is not set, we try to get the time from a
+ * live consensus. */
uint64_t
hs_get_next_time_period_num(time_t now)
{
return hs_get_time_period_num(now) + 1;
}
/* Get the number of the _previous_ HS time period, given that the current
* time is now. */
uint64_t
hs_get_previous_time_period_num(time_t now)
{
return hs_get_time_period_num(now) - 1;
}
-/* Return the start time of the upcoming time period based on now. */
+/* Return the start time of the upcoming time period based on now. If
+ now is not set, we try to get the time ourselves from a live
+ consensus. */
time_t
hs_get_start_time_of_next_time_period(time_t now)
{
@@ -235,7 +235,7 @@ get_time_period_length(void)
}
/** Get the HS time period number at time now. If now is not set,
- * we try to get the time ourselves. */
+ * we try to get the time ourselves from a live consensus. */
uint64_t
hs_get_time_period_num(time_t now)
@@ -269,22 +269,26 @@ hs_get_time_period_num(time_t now)
return hs_get_time_period_num(now) + 1;
}
-/* Get the number of the _previous_ HS time period, given that the current
- * time is now. */
+/* Get the number of the _previous_ HS time period, given that the current time
+ * is now. If now is not set, we try to get the time from a live
+ * consensus. */
uint64_t
hs_get_previous_time_period_num(time_t now)